@@ -1,11 +1,9 @@
 use strict;
 use warnings;
 package Task::Yeb;
-BEGIN {
-  $Task::Yeb::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: All the approved Yeb plugins in one Task
-$Task::Yeb::VERSION = '20140705.000';
+$Task::Yeb::VERSION = '20160218.000';
 
 1;
 
@@ -21,7 +19,7 @@ Task::Yeb - All the approved Yeb plugins in one Task
 
 =head1 VERSION
 
-version 20140705.000
+version 20160218.000
 
 =head1 TASK CONTENTS
 
@@ -47,7 +45,7 @@ Localization via L<Locale::Simple>
 
 =head2 Models
 
-=head3 L<Yeb::Plugin::DBIC> 0.100
+=head3 L<Yeb::Plugin::DBIC> 0.001
 
 Accessing a L<DBIx::Class> schema
 
